==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/so-SO/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Agabka waa la hubiyay',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Hantida la hubiyay',
    'Asset_Checkout_Notification' => 'Hantida la hubiyay',
    'Confirm_Accessory_Checkin' => 'Xaqiijinta hubinta dheeraadka ah',
    'Confirm_Asset_Checkin' => 'Xaqiijinta hubinta hantida',
    'Confirm_accessory_delivery' => 'Xaqiijinta gaarsiinta agabka',
    'Confirm_asset_delivery' => 'Xaqiijinta keenista hantida',
    'Confirm_consumable_delivery' => 'Xaqiijinta keenista la isticmaali karo',
    'Confirm_license_delivery' => 'Xaqiijinta bixinta shatiga',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Maalmo',
    'Expected_Checkin_Date' => 'Hantida lagugu hubiyay waa in lagugu soo celiyaa :date',
    'Expected_Checkin_Notification' => 'Xusuusin: :name wakhtiga kama dambaysta ah ee hubinta ayaa soo dhow',
    'Expected_Checkin_Report' => 'Warbixinta hubinta hantida la filayo',
    'Expiring_Assets_Report' => 'Warbixinta hantida dhaceysa.',
    'Expiring_Licenses_Report' => 'Warbixinta Shatiyada dhacaya.',
    'Item_Request_Canceled' => 'Codsiga shayga waa la joojiyay',
    'Item_Requested' => 'Shayga la codsaday',
    'License_Checkin_Notification' => 'Shatiga waa la hubiyay',
    'License_Checkout_Notification' => 'License checked out',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Warbixinta Alaabada Hoose',
    'a_user_canceled' => 'Isticmaaluhu waxa uu joojiyay shay codsi ah oo ku jiray mareegaha',
    'a_user_requested' => 'Isticmaaluhu wuxuu ka codsaday shay shabakada',
    'acceptance_asset_accepted' => 'Isticmaaluhu waa aqbalay shay',
    'acceptance_asset_declined' => 'Isticmaaluhu waa diiday shay',
    'accessory_name' => 'Magaca dheeriga ah',
    'additional_notes' => 'Qoraalo Dheeraad ah',
    'admin_has_created' => 'Maamule ayaa akoon kaaga sameeyay :web website.',
    'asset' => 'Hantida',
    'asset_name' => 'Magaca Hantida',
    'asset_requested' => 'Hantida la codsaday',
    'asset_tag' => 'Hantida Tag',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Loo xilsaaray',
    'best_regards' => 'Salaan wanagsan,',
    'canceled' => 'La joojiyay',
    'checkin_date' => 'Taariikhda la soo galayo',
    'checkout_date' => 'Taariikhda Bixinta',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Laga soo hubiyay',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Fadlan dhagsii xiriirka hoose si aad u xaqiijiso inaad heshay agabka.',
    'click_on_the_link_asset' => 'Fadlan ku dhufo xiriirka hoose si aad u xaqiijiso inaad heshay hantida.',
    'click_to_confirm' => 'Fadlan dhagsii xidhiidhka soo socda si aad u xaqiijiso :web akoonkaaga:',
    'current_QTY' => 'QTY-da hadda',
    'days' => 'Maalmo',
    'expecting_checkin_date' => 'Taariikhda la filayo',
    'expires' => 'Dhacaya',
    'hello' => 'Hello',
    'hi' => 'Hi',
    'i_have_read' => 'Waan akhriyay oo waan aqbalay shuruudaha isticmaalka, waxaana helay shaygan.',
    'inventory_report' => 'Warbixinta Alaabada',
    'item' => 'Shayga',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'link_to_update_password' => 'Fadlan dhagsii xidhiidhka soo socda si aad u cusboonaysiiso :web eraygaaga sirta ah:',
    'login' => 'Soo gal',
    'login_first_admin' => 'Soo gal rakibaaddaada cusub ee Snipe-IT adoo isticmaalaya aqoonsiga hoose:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'min_QTY' => 'Min QTY',
    'name' => 'Magaca',
    'new_item_checked' => 'Shay cusub ayaa lagu hubiyay magacaaga hoostiisa.',
    'notes' => 'Xusuusin',
    'password' => 'Password-ka',
    'password_reset' => 'Dib u habaynta erayga sirta ah',
    'read_the_terms' => 'Fadlan hoos ka akhri shuruudaha isticmaalka.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'La codsaday',
    'reset_link' => 'Xidhiidhka Dib-u-dejinta Furahaaga',
    'reset_password' => 'Riix halkan si aad dib ugu dejiso eraygaaga sirta ah:',
    'rights_reserved' => 'Dhammaan xuquuqda waa la dhowray.',
    'serial' => 'Taxane',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Alaab-qeybiye',
    'tag' => 'Tag',
    'test_email' => 'Tijaabi iimaylka Snipe-IT',
    'test_mail_text' => 'Kani waa imtixaan ka yimid Nidaamka Maareynta Hantida Snipe-IT. Haddii aad tan heshay, boostada ayaa shaqaynaysa :)',
    'the_following_item' => 'Shayga soo socda ayaa la hubiyay: ',
    'to_reset' => 'Si dib loogu dejiyo :web eraygaaga sirta ah, buuxi foomkan:',
    'type' => 'Nooca',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Isticmaale',
    'username' => 'Magaca isticmaale',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Soo dhawoow :name',
    'welcome_to' => 'Ku soo dhawoow :web!',
    'your_assets' => 'Arag Hantidaada',
    'your_credentials' => 'Aqoonsigaaga Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/so-SO/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Agabka waa la hubiyay',
    'Accessory_Checkout_Notification' => 'Accessory checked out|:count Accessories checked out',
    'Asset_Checkin_Notification' => 'Asset checked in: :tag',
    'Asset_Checkout_Notification' => 'Asset checked out: :tag',
    'Confirm_Accessory_Checkin' => 'Xaqiijinta hubinta dheeraadka ah',
    'Confirm_Asset_Checkin' => 'Xaqiijinta hubinta hantida',
    'Confirm_component_checkin' => 'Component checkin confirmation',
    'Confirm_accessory_delivery' => 'Xaqiijinta gaarsiinta agabka',
    'Confirm_asset_delivery' => 'Xaqiijinta keenista hantida',
    'Confirm_consumable_delivery' => 'Xaqiijinta keenista la isticmaali karo',
    'Confirm_component_delivery' => 'Component delivery confirmation',
    'Confirm_license_delivery' => 'Xaqiijinta bixinta shatiga',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Component_checkout_notification' => 'Component checked out',
    'Component_checkin_notification' => 'Component checked in',
    'Days' => 'Maalmo',
    'Expected_Checkin_Date' => 'Hantida lagugu hubiyay waa in lagugu soo celiyaa :date',
    'Expected_Checkin_Notification' => 'Xusuusin: :name wakhtiga kama dambaysta ah ee hubinta ayaa soo dhow',
    'Expected_Checkin_Report' => 'Warbixinta hubinta hantida la filayo',
    'Expiring_Assets_Report' => 'Warbixinta hantida dhaceysa',
    'Expiring_Licenses_Report' => 'Warbixinta Shatiyada dhacaya',
    'Item_Request_Canceled' => 'Codsiga shayga waa la joojiyay',
    'Item_Requested' => 'Shayga la codsaday',
    'License_Checkin_Notification' => 'Shatiga waa la hubiyay',
    'License_Checkout_Notification' => 'License checked out',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Warbixinta Alaabada Hoose',
    'a_user_canceled' => 'Isticmaaluhu waxa uu joojiyay shay codsi ah oo ku jiray mareegaha',
    'a_user_requested' => 'Isticmaaluhu wuxuu ka codsaday shay shabakada',
    'acceptance_asset_accepted_to_user' => 'You have accepted an item assigned to you by :site_name|You have accepted :qty items assigned to you by :site_name',
    'acceptance_asset_accepted' => 'Isticmaaluhu waa aqbalay shay',
    'acceptance_asset_declined' => 'Isticmaaluhu waa diiday shay',
    'send_pdf_copy' => 'Send a copy of this acceptance to my email address',
    'accessory_name' => 'Magaca dheeriga ah',
    'additional_notes' => 'Qoraalo Dheeraad ah',
    'admin_has_created' => 'An administrator has created an account for you on the :web website. Please find your username below, and click on the link to set a password.',
    'asset' => 'Hantida',
    'asset_name' => 'Magaca Hantida',
    'asset_requested' => 'Hantida la codsaday',
    'asset_tag' => 'Hantida Tag',
    'assets_warrantee_alert' => 'There is :count asset with an expiring warranty or that are reaching their end of life in the next :threshold days.|There are :count assets with expiring warranties or that are reaching their end of life in the next :threshold days.',
    'assigned_to' => 'Loo xilsaaray',
    'eol' => 'EOL',
    'best_regards' => 'Salaan wanagsan,',
    'canceled' => 'La joojiyay',
    'checkin_date' => 'Taariikhda la soo galayo',
    'checkout_date' => 'Taariikhda Bixinta',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Laga soo hubiyay',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Fadlan dhagsii xiriirka hoose si aad u xaqiijiso inaad heshay agabka.',
    'click_on_the_link_asset' => 'Fadlan ku dhufo xiriirka hoose si aad u xaqiijiso inaad heshay hantida.',
    'click_to_confirm' => 'Fadlan dhagsii xidhiidhka soo socda si aad u xaqiijiso :web akoonkaaga:',
    'current_QTY' => 'QTY-da hadda',
    'days' => 'Maalmo',
    'expecting_checkin_date' => 'Taariikhda la filayo',
    'expires' => 'Dhacaya',
    'terminates' => 'Terminates',
    'following_accepted' => 'The following was accepted',
    'following_declined' => 'The following was declined',
    'hello' => 'Hello',
    'hi' => 'Hi',
    'i_have_read' => 'Waan akhriyay oo waan aqbalay shuruudaha isticmaalka, waxaana helay shaygan.',
    'initiated_accepted' => 'A checkout you initiated was accepted',
    'initiated_declined' => 'A checkout you initiated was declined',
    'inventory_report' => 'Warbixinta Alaabada',
    'item' => 'Shayga',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring or terminating in the next :threshold days.|There are :count licenses expiring or terminating in the next :threshold days.',
    'link_to_update_password' => 'Fadlan dhagsii xidhiidhka soo socda si aad u cusboonaysiiso :web eraygaaga sirta ah:',
    'login' => 'Soo gal',
    'login_first_admin' => 'Soo gal rakibaaddaada cusub ee Snipe-IT adoo isticmaalaya aqoonsiga hoose:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'min_QTY' => 'Min QTY',
    'name' => 'Magaca',
    'new_item_checked' => 'A new item has been checked out under your name, details are below.|:count new items have been checked out under your name, details are below.',
    'new_item_checked_with_acceptance' => 'A new item has been checked out under your name that requires acceptance, details are below.|:count new items have been checked out under your name that requires acceptance, details are below.',
    'new_item_checked_location' => 'A new item has been checked out to :location, details are below.|:count new items have been checked out to :location, details are below.',
    'recent_item_checked' => 'An item was recently checked out under your name that requires acceptance, details are below.',
    'notes' => 'Xusuusin',
    'password' => 'Password-ka',
    'password_reset' => 'Dib u habaynta erayga sirta ah',
    'read_the_terms' => 'Fadlan hoos ka akhri shuruudaha isticmaalka.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'La codsaday',
    'reset_link' => 'Xidhiidhka Dib-u-dejinta Furahaaga',
    'reset_password' => 'Riix halkan si aad dib ugu dejiso eraygaaga sirta ah:',
    'rights_reserved' => 'Dhammaan xuquuqda waa la dhowray.',
    'serial' => 'Taxane',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Alaab-qeybiye',
    'tag' => 'Tag',
    'test_email' => 'Tijaabi iimaylka Snipe-IT',
    'test_mail_text' => 'Kani waa imtixaan ka yimid Nidaamka Maareynta Hantida Snipe-IT. Haddii aad tan heshay, boostada ayaa shaqaynaysa :)',
    'the_following_item' => 'Shayga soo socda ayaa la hubiyay: ',
    'to_reset' => 'Si dib loogu dejiyo :web eraygaaga sirta ah, buuxi foomkan:',
    'type' => 'Nooca',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Isticmaale',
    'username' => 'Magaca isticmaale',
    'unaccepted_asset_reminder' => 'Reminder: You have Unaccepted Assets.',
    'welcome' => 'Soo dhawoow :name',
    'welcome_to' => 'Ku soo dhawoow :web!',
    'your_assets' => 'Arag Hantidaada',
    'your_credentials' => 'Aqoonsigaaga Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];
